Async executor module for Moirai.
This module declares submodules for task executor components following SLAP/SRP.
Re-exports
pub use core::AsyncExecutor;pub use handle::AsyncHandle;pub use stats::ExecutorStats;
Async executor module for Moirai.
This module declares submodules for task executor components following SLAP/SRP.
pub use core::AsyncExecutor;pub use handle::AsyncHandle;pub use stats::ExecutorStats;