Module timer

Module timer 

Async timer primitives for Moirai concurrency library.

Following SLAP principle with focused responsibility on time-based async operations.

Re-exports

pub use delay::Delay;
pub use interval::Interval;
pub use limiter::RateLimiter;
pub use limiter::RatePermit;
pub use timeout::Timeout;
pub use timeout::TimeoutError;
pub use wheel::TimerCommand;
pub use wheel::TimerWheel;

Modules

delay
One-shot delay futures.
interval
Repeating interval ticks.
limiter
Time-based rate limiting.
timeout
Deadline wrappers over futures.
wheel
Hierarchical timing-wheel implementation. Timer wheel data structure for explicit timer management.

Functions

interval
Create a new interval timer
interval_at
Create an interval timer that starts at a specific time
sleep
Create a delay future that completes after the specified duration
timeout
Timeout wrapper for futures with comprehensive cancellation