Async/await support for Moirai concurrency library.
This module provides async runtime integration for Moirai, enabling seamless interop between sync and async tasks while maintaining high performance.
Following SLAP principle, this module now serves as a facade that re-exports functionality from focused, single-responsibility modules.
Re-exports
pub use io::AsyncBufRead;pub use io::AsyncLength;pub use io::AsyncMemReader;pub use io::AsyncRead;pub use io::AsyncReadAt;pub use io::AsyncReadExt;pub use io::AsyncWrite;pub use io::AsyncWriteExt;pub use io::MoiraiCompat;pub use io::TokioCompat;pub use executor::AsyncExecutor;pub use executor::AsyncHandle;pub use executor::ExecutorStats;pub use timer::Delay;pub use timer::Interval;pub use timer::RateLimiter;pub use timer::RatePermit;pub use timer::Timeout;pub use timer::TimeoutError;pub use timer::TimerCommand;pub use timer::TimerWheel;pub use timer::interval;pub use timer::interval;pub use timer::interval_at;pub use timer::sleep;pub use timer::timeout;pub use timer::timeout;pub use net::ConnectionInfo;pub use net::ConnectionPool;pub use net::ConnectionStats;pub use net::TcpListener;pub use net::TcpServerConfig;pub use net::TcpServerStats;pub use net::TcpStream;pub use net::UdpConfig;pub use net::UdpSocket;pub use net::UdpSocketStats;pub use fs::File;pub use fs::FileStats;pub use fs::append;pub use fs::append_str;pub use fs::copy;pub use fs::create_dir;pub use fs::create_dir_all;pub use fs::metadata;pub use fs::read;pub use fs::read_to_string;pub use fs::remove_dir;pub use fs::remove_dir_all;pub use fs::remove_file;pub use fs::rename;pub use fs::write;pub use fs::write_str;pub use sync::Broadcast;pub use sync::BroadcastError;pub use sync::BroadcastReceiver;pub use sync::BroadcastSender;pub use sync::Condvar;pub use sync::Mutex;pub use sync::MutexGuard;pub use sync::Notify;pub use sync::RwLock;pub use sync::Semaphore;pub use sync::SemaphorePermit;pub use sync::Watch;pub use sync::WatchError;pub use sync::WatchReceiver;pub use sync::WatchSender;
Modules
- executor
- Async executor module for Moirai.
- fs
- Async file I/O primitives for Moirai concurrency library.
- io
- Async I/O traits and compatibility utilities for Moirai.
- net
- Async networking primitives for Moirai concurrency library.
- sync
- Advanced async synchronization primitives for Moirai
- timer
- Async timer primitives for Moirai concurrency library.
Structs
- File
Open Options - Declarative open-mode configuration for
File::open_with.
Attribute Macros
- main
- Marks an
async fn mainas the program entry point.